@@ -23,8 +23,11 @@
  */
 package htsjdk.samtools;
 
+import htsjdk.samtools.cram.ref.CRAMReferenceSource;
 import htsjdk.samtools.cram.ref.ReferenceSource;
+import htsjdk.samtools.cram.structure.CRAMEncodingStrategy;
 import htsjdk.samtools.util.BlockCompressedOutputStream;
+import htsjdk.samtools.util.FileExtensions;
 import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.Md5CalculatingOutputStream;
@@ -37,6 +40,7 @@ import java.io.OutputStream;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.zip.Deflater;
+import static htsjdk.samtools.SamReader.Type.*;
 
 /**
  * Create a writer for writing SAM, BAM, or CRAM files.
@@ -410,7 +414,7 @@ public class SAMFileWriterFactory implements Cloneable {
     }
 
     /**
-     * Create either a SAM or a BAM writer based on examination of the outputFile extension.
+     * Create either a SAM or a BAM writer based on examination of the outputFile extension, defaults to BAM writer.
      *
      * @param header     entire header. Sort order is determined by the sortOrder property of this arg.
      * @param presorted  presorted if true, SAMRecords must be added to the SAMFileWriter in order that agrees with header.sortOrder.
@@ -431,24 +435,26 @@ public class SAMFileWriterFactory implements Cloneable {
      */
     public SAMFileWriter makeSAMOrBAMWriter(final SAMFileHeader header, final boolean presorted, final Path outputPath) {
         final String filename = outputPath.getFileName().toString();
-        if (filename.endsWith(BamFileIoUtils.BAM_FILE_EXTENSION)) {
+        if (SAM_TYPE.hasValidFileExtension(filename)) {
+            return makeSAMWriter(header, presorted, outputPath);
+        } else {
+            if (!BAM_TYPE.hasValidFileExtension(filename)) {
+                log.info("Unknown file extension, assuming BAM format when writing file: " + outputPath.toUri().toString());
+            }
             return makeBAMWriter(header, presorted, outputPath);
         }
-        if (filename.endsWith(".sam")) {
-            return makeSAMWriter(header, presorted, outputPath);
-        }
-        return makeBAMWriter(header, presorted, outputPath);
     }
 
     /**
      *
      * Create a SAM, BAM or CRAM writer based on examination of the outputFile extension.
+     * The method assumes BAM file format for unknown file extensions.
      *
      * @param header header. Sort order is determined by the sortOrder property of this arg.
      * @param presorted if true, SAMRecords must be added to the SAMFileWriter in order that agrees with header.sortOrder.
-     * @param outputFile where to write the output.  Must end with .sam, .bam or .cram.
+     * @param outputFile where to write the output.  Should end with .sam, .bam or .cram.
      * @param referenceFasta reference sequence file
-     * @return SAMFileWriter appropriate for the file type specified in outputFile
+     * @return SAMFileWriter appropriate for SAM and CRAM file types specified in outputFile, or a BAM writer for all other types
      *
      */
     public SAMFileWriter makeWriter(final SAMFileHeader header, final boolean presorted, final File outputFile, final File referenceFasta) {
@@ -483,11 +489,11 @@ public class SAMFileWriterFactory implements Cloneable {
      *
      */
     public SAMFileWriter makeWriter(final SAMFileHeader header, final boolean presorted, final Path outputPath, final Path referenceFasta) {
-        if (null != outputPath && outputPath.toString().endsWith(SamReader.Type.CRAM_TYPE.fileExtension())) {
+        final String filename = outputPath.getFileName().toString();
+        if (CRAM_TYPE.hasValidFileExtension(filename)) {
             return makeCRAMWriter(header, presorted, outputPath, referenceFasta);
-        }
-        else {
-            return makeSAMOrBAMWriter(header, presorted, outputPath);
+        } else {
+            return makeSAMOrBAMWriter (header, presorted, outputPath);
         }
     }
 
@@ -519,9 +525,7 @@ public class SAMFileWriterFactory implements Cloneable {
      */
     public CRAMFileWriter makeCRAMWriter(final SAMFileHeader header, final OutputStream stream, final Path referenceFasta) {
         // create the CRAMFileWriter directly without propagating factory settings
-        final CRAMFileWriter writer = new CRAMFileWriter(stream, new ReferenceSource(referenceFasta), header, null);
-        setCRAMWriterDefaults(writer);
-        return writer;
+        return new CRAMFileWriter(stream, new ReferenceSource(referenceFasta), header, null);
     }
 
     /**
@@ -628,17 +632,29 @@ public class SAMFileWriterFactory implements Cloneable {
             final boolean presorted,
             final Path outputFile,
             final Path referenceFasta) {
+
+        final CRAMReferenceSource referenceSource;
+        if (referenceFasta == null) {
+            log.info("Reference fasta is not provided when writing CRAM file " + outputFile.toUri().toString());
+            log.info("Will attempt to use a default reference or download as set by defaults:");
+            log.info("Default REFERENCE_FASTA (-Dsamjdk.reference_fasta): " + Defaults.REFERENCE_FASTA);
+            log.info("Default USE_CRAM_REF_DOWNLOAD (-Dsamjdk.use_cram_ref_download): " + Defaults.USE_CRAM_REF_DOWNLOAD);
+
+            referenceSource = ReferenceSource.getDefaultCRAMReferenceSource();
+        } else {
+            referenceSource = new ReferenceSource(referenceFasta);
+        }
         OutputStream cramOS = null;
-        OutputStream indexOS = null ;
+        OutputStream indexOS = null;
 
         if (createIndex) {
             if (!IOUtil.isRegularPath(outputFile)) {
                 log.warn("Cannot create index for CRAM because output file is not a regular file: " + outputFile.toUri());
-            }
-            else {
-                final Path indexPath = IOUtil.addExtension(outputFile, BAMIndex.BAMIndexSuffix);
+            } else {
+                final Path indexPath = IOUtil.addExtension(outputFile, FileExtensions.BAI_INDEX);
                 try {
-                    indexOS = Files.newOutputStream(indexPath);
+
+                    indexOS = Files.newOutputStream(indexPath) ;
                 }
                 catch (final IOException ioe) {
                     throw new RuntimeIOException("Error creating index file for: " + indexPath.toUri(), ioe);
@@ -648,8 +664,7 @@ public class SAMFileWriterFactory implements Cloneable {
 
         try {
             cramOS = IOUtil.maybeBufferOutputStream(Files.newOutputStream(outputFile), bufferSize);
-        }
-        catch (final IOException ioe) {
+        } catch (final IOException ioe) {
             throw new RuntimeIOException("Error creating CRAM file: " + outputFile.toUri(), ioe);
         }
 
@@ -658,7 +673,7 @@ public class SAMFileWriterFactory implements Cloneable {
                 createMd5File ? new Md5CalculatingOutputStream(cramOS, md5Path) : cramOS,
                 indexOS,
                 presorted,
-                new ReferenceSource(referenceFasta),
+                referenceSource,
                 header,
                 outputFile.toUri().toString());
         setCRAMWriterDefaults(writer);
@@ -668,8 +683,8 @@ public class SAMFileWriterFactory implements Cloneable {
 
     // Set the default CRAM writer preservation parameters
     private void setCRAMWriterDefaults(final CRAMFileWriter writer) {
-        writer.setPreserveReadNames(true);
-        writer.setCaptureAllTags(true);
+        //TODO: set encoding params
+        //writer.setEncodingParams(new CRAMEncodingStrategy());
     }
 
     @Override
