@@ -28,6 +28,7 @@ import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.SequenceUtil;
 import htsjdk.samtools.util.StringUtil;
+import htsjdk.utils.ValidationUtils;
 
 import java.io.File;
 import java.io.IOException;
@@ -36,6 +37,7 @@ import java.lang.ref.WeakReference;
 import java.net.URL;
 import java.nio.file.Path;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
@@ -58,6 +60,12 @@ public class ReferenceSource implements CRAMReferenceSource {
 
     private final Map<String, WeakReference<byte[]>> cacheW = new HashMap<>();
 
+    // Optimize for locality of reference by maintaining the backing reference bases for the most recent request.
+    // Failure to do this will result in the bases being aggressively GC'd when the only other reference to them
+    // is the weak reference hash map above, resulting in much thrashing.
+    private byte[] backingReferenceBases;
+    private int backingContigIndex;
+
     public ReferenceSource(final File file) {
         this(IOUtil.toPath(file));
     }
@@ -179,6 +187,40 @@ public class ReferenceSource implements CRAMReferenceSource {
         return null;
     }
 
+    @Override
+    public byte[] getReferenceBasesByRegion(
+            final SAMSequenceRecord sequenceRecord,
+            final int zeroBasedStart,
+            final int requestedRegionLength) {
+        ValidationUtils.validateArg(zeroBasedStart >= 0, "start must be >= 0");
+
+        // this implementation maintains the entire reference sequence, and hands out whatever region
+        // of it is requested
+        final byte[] bases = getBackingBases(sequenceRecord);
+
+        if (bases != null) {
+            // cache the backing bases to prevent thrashing due to aggressive GC
+            backingReferenceBases = bases;
+            backingContigIndex = sequenceRecord.getSequenceIndex();
+
+            if (zeroBasedStart >= bases.length) {
+                throw new IllegalArgumentException(String.format("Requested start %d is beyond the sequence length %s",
+                        zeroBasedStart,
+                        sequenceRecord.getSequenceName()));
+            }
+            return Arrays.copyOfRange(bases, zeroBasedStart, Math.min(bases.length, zeroBasedStart + requestedRegionLength));
+        }
+        return bases;
+    }
+
+    private byte[] getBackingBases(final SAMSequenceRecord sequenceRecord) {
+        if (backingReferenceBases != null && backingContigIndex == sequenceRecord.getSequenceIndex()) {
+            return backingReferenceBases;
+        } else {
+            return getReferenceBases(sequenceRecord, false);
+        }
+    }
+
     private byte[] findBasesByName(final String name, final boolean tryVariants) {
         if (rsFile == null || !rsFile.isIndexed())
             return null;
