@@ -11,13 +11,13 @@ import java.util.zip.GZIPOutputStream;
  * @author Tim Fennell
  */
 public class CustomGzipOutputStream extends GZIPOutputStream {
-    CustomGzipOutputStream(final OutputStream outputStream, final int bufferSize, final int compressionLevel) throws
+    public CustomGzipOutputStream(final OutputStream outputStream, final int bufferSize, final int compressionLevel) throws
             IOException {
         super(outputStream, bufferSize);
         this.def.setLevel(compressionLevel);
     }
 
-    CustomGzipOutputStream(final OutputStream outputStream, final int compressionLevel) throws IOException {
+    public CustomGzipOutputStream(final OutputStream outputStream, final int compressionLevel) throws IOException {
         super(outputStream);
         this.def.setLevel(compressionLevel);
     }
