@@ -25,19 +25,22 @@
 package htsjdk.variant.utils;
 
 import htsjdk.samtools.*;
+import htsjdk.samtools.cram.build.CramIO;
+import htsjdk.samtools.cram.structure.Container;
+import htsjdk.samtools.cram.structure.CramHeader;
 import htsjdk.samtools.reference.ReferenceSequenceFileFactory;
-import htsjdk.samtools.util.BufferedLineReader;
-import htsjdk.samtools.util.CollectionUtil;
-import htsjdk.samtools.util.IOUtil;
-import htsjdk.samtools.util.IntervalList;
+import htsjdk.samtools.util.*;
 import htsjdk.tribble.util.ParsingUtils;
 import htsjdk.variant.vcf.VCFFileReader;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
+import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Optional;
 
 /**
  * Small class for loading a SAMSequenceDictionary from a file
@@ -46,17 +49,17 @@ import java.util.Collection;
 public class SAMSequenceDictionaryExtractor {
 
     enum TYPE {
-        FASTA(ReferenceSequenceFileFactory.FASTA_EXTENSIONS) {
+        FASTA(FileExtensions.FASTA) {
 
             @Override
-            SAMSequenceDictionary extractDictionary(Path reference) {
+            SAMSequenceDictionary extractDictionary(final Path reference) {
                 final SAMSequenceDictionary dict = ReferenceSequenceFileFactory.getReferenceSequenceFile(reference).getSequenceDictionary();
                 if (dict == null)
                     throw new SAMException("Could not find dictionary next to reference file " + reference.toUri().toString());
                 return dict;
             }
         },
-        DICTIONARY(IOUtil.DICT_FILE_EXTENSION) {
+        DICTIONARY(FileExtensions.DICT) {
 
             @Override
             SAMSequenceDictionary extractDictionary(final Path dictionary) {
@@ -70,26 +73,44 @@ public class SAMSequenceDictionaryExtractor {
                 }
             }
         },
-        SAM(IOUtil.SAM_FILE_EXTENSION, BamFileIoUtils.BAM_FILE_EXTENSION) {
+        CRAM(FileExtensions.CRAM) {
+            
+            @Override
+            SAMSequenceDictionary extractDictionary(final Path cramPath) {
+                IOUtil.assertFileIsReadable(cramPath);
+                try (final InputStream in = Files.newInputStream(cramPath)) {
+                    final CramHeader cramHeader = CramIO.readCramHeader(in);
+                    final Optional<SAMFileHeader> samHeader = Optional.ofNullable(
+                            Container.readSAMFileHeaderContainer(cramHeader.getCRAMVersion(), in, cramPath.toString()));
+                    if (samHeader.isPresent()) {
+                        return samHeader.get().getSequenceDictionary();
+                    }
+                } catch (IOException e) {
+                    throw new RuntimeIOException(e);
+                }
+                throw new SAMException(String.format("Can't retrieve sequence dictionary from %s", cramPath));
+            }
+        },
+        SAM(FileExtensions.SAM, FileExtensions.BAM) {
 
             @Override
-            SAMSequenceDictionary extractDictionary(Path sam) {
+            SAMSequenceDictionary extractDictionary(final Path sam) {
                 return SamReaderFactory.makeDefault().getFileHeader(sam).getSequenceDictionary();
             }
         },
-        VCF(IOUtil.VCF_EXTENSIONS) {
+        VCF(FileExtensions.VCF_LIST.toArray(new String[0])) {
 
             @Override
-            SAMSequenceDictionary extractDictionary(Path vcf) {
+            SAMSequenceDictionary extractDictionary(final Path vcf) {
                 try (VCFFileReader vcfPathReader = new VCFFileReader(vcf, false)){
                     return vcfPathReader.getFileHeader().getSequenceDictionary();
                 }
             }
         },
-        INTERVAL_LIST(IOUtil.INTERVAL_LIST_FILE_EXTENSION) {
+        INTERVAL_LIST(FileExtensions.INTERVAL_LIST, FileExtensions.COMPRESSED_INTERVAL_LIST) {
 
             @Override
-            SAMSequenceDictionary extractDictionary(Path intervalList) {
+            SAMSequenceDictionary extractDictionary(final Path intervalList) {
                 return IntervalList.fromPath(intervalList).getHeader().getSequenceDictionary();
             }
         };
