@@ -23,36 +23,42 @@
  */
 package htsjdk.samtools;
 
-import htsjdk.HtsjdkTest;
 import com.google.common.jimfs.Configuration;
 import com.google.common.jimfs.Jimfs;
-import htsjdk.samtools.cram.build.CramIO;
+import htsjdk.HtsjdkTest;
 import htsjdk.samtools.cram.ref.ReferenceSource;
+import htsjdk.samtools.seekablestream.SeekableFileStream;
+import htsjdk.samtools.util.FileExtensions;
 import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.RuntimeIOException;
-import java.nio.file.Path;
-import java.nio.file.Files;
-import java.nio.file.FileSystem;
-import java.nio.file.Paths;
 import org.testng.Assert;
 import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 
 import java.io.*;
+import java.nio.file.FileSystem;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.nio.file.Paths;
 
+import static htsjdk.samtools.SamReader.Type.*;
+
+@SuppressWarnings("EmptyTryBlock")
 public class SAMFileWriterFactoryTest extends HtsjdkTest {
 
     private static final File TEST_DATA_DIR = new File("src/test/resources/htsjdk/samtools");
 
-    /** PIC-442Confirm that writing to a special file does not cause exception when writing additional files. */
-    @Test(groups={"unix"})
+    /**
+     * PIC-442Confirm that writing to a special file does not cause exception when writing additional files.
+     */
+    @Test(groups = {"unix"})
     public void specialFileWriterTest() {
         createSmallBam(new File("/dev/null"));
     }
 
     @Test()
     public void ordinaryFileWriterTest() throws Exception {
-        final File outputFile = File.createTempFile("tmp.", BamFileIoUtils.BAM_FILE_EXTENSION);
+        final File outputFile = File.createTempFile("tmp.", FileExtensions.BAM);
         outputFile.delete();
         outputFile.deleteOnExit();
         createSmallBam(outputFile);
@@ -68,10 +74,10 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
     @Test()
     public void ordinaryPathWriterTest() throws Exception {
         try (FileSystem jimfs = Jimfs.newFileSystem(Configuration.unix())) {
-            final Path outputPath = jimfs.getPath("ordinaryPathWriterTest" + BamFileIoUtils.BAM_FILE_EXTENSION);
+            final Path outputPath = jimfs.getPath("ordinaryPathWriterTest" + FileExtensions.BAM);
             createSmallBam(outputPath);
             final Path indexPath = SamFiles.findIndex(outputPath);
-            final Path md5File = IOUtil.addExtension(outputPath,  ".md5");
+            final Path md5File = IOUtil.addExtension(outputPath, ".md5");
             Assert.assertTrue(Files.size(outputPath) > 0);
             Assert.assertTrue(Files.size(indexPath) > 0);
             Assert.assertTrue(Files.size(md5File) > 0);
@@ -89,97 +95,88 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
         }
     }
 
-    @Test(description="create a BAM in memory,  should start with GZipInputStream.GZIP_MAGIC")
-    public void inMemoryBam()  throws Exception  {
-    	ByteArrayOutputStream os=new ByteArrayOutputStream();
-    	createSmallBamToOutputStream(os,true);
-    	os.flush();
-    	os.close();
-    	byte blob[]=os.toByteArray();
+    @Test(description = "create a BAM in memory,  should start with GZipInputStream.GZIP_MAGIC")
+    public void inMemoryBam() throws Exception {
+        final ByteArrayOutputStream os = new ByteArrayOutputStream();
+        createSmallBamToOutputStream(os, true);
+        os.flush();
+        os.close();
+        final byte blob[] = os.toByteArray();
         Assert.assertTrue(blob.length > 2);
-        int head = ((int) blob[0] & 0xff) | ((blob[1] << 8 ) & 0xff00 );
+        final int head = ((int) blob[0] & 0xff) | ((blob[1] << 8) & 0xff00);
         Assert.assertTrue(java.util.zip.GZIPInputStream.GZIP_MAGIC == head);
     }
 
-    @Test(description="create a SAM in memory,  should start with '@HD'")
-    public void inMemorySam()  throws Exception  {
-    	ByteArrayOutputStream os=new ByteArrayOutputStream();
-    	createSmallBamToOutputStream(os,false);
-    	os.flush();
-    	os.close();
-    	String sam=new String(os.toByteArray());
+    @Test(description = "create a SAM in memory,  should start with '@HD'")
+    public void inMemorySam() throws Exception {
+        final ByteArrayOutputStream os = new ByteArrayOutputStream();
+        createSmallBamToOutputStream(os, false);
+        os.flush();
+        os.close();
+        final String sam = new String(os.toByteArray());
         Assert.assertFalse(sam.isEmpty());
-        Assert.assertTrue(sam.startsWith("@HD\t"),"SAM: bad prefix");
+        Assert.assertTrue(sam.startsWith("@HD\t"), "SAM: bad prefix");
     }
 
-    @Test(description="Read and then write SAM to verify header attribute ordering does not change depending on JVM version")
-    public void samRoundTrip()  throws Exception  {
+    @Test(description = "Read and then write SAM to verify header attribute ordering does not change depending on JVM version")
+    public void samRoundTrip() throws Exception {
         final File input = new File(TEST_DATA_DIR, "roundtrip.sam");
 
-        final SamReader reader = SamReaderFactory.makeDefault().open(input);
         final File outputFile = File.createTempFile("roundtrip-out", ".sam");
         outputFile.delete();
         outputFile.deleteOnExit();
-        FileOutputStream os = new FileOutputStream(outputFile);
         final SAMFileWriterFactory factory = new SAMFileWriterFactory();
-        final SAMFileWriter writer = factory.makeSAMWriter(reader.getFileHeader(), false, os);
-        for (SAMRecord rec : reader) {
-            writer.addAlignment(rec);
+        try (SamReader reader = SamReaderFactory.makeDefault().open(input);
+             SAMFileWriter writer = factory.makeSAMWriter(reader.getFileHeader(), false, new FileOutputStream(outputFile))) {
+            for (SAMRecord rec : reader) {
+                writer.addAlignment(rec);
+            }
         }
-        writer.close();
-        os.close();
 
-        InputStream is = new FileInputStream(input);
-        String originalsam = IOUtil.readFully(is);
-        is.close();
+        final String originalsam;
+        try (InputStream is = new FileInputStream(input)) {
+            originalsam = IOUtil.readFully(is);
+        }
 
-        is = new FileInputStream(outputFile);
-        String writtensam = IOUtil.readFully(is);
-        is.close();
+        final String writtenSam;
+        try (InputStream is = new FileInputStream(outputFile)) {
+            writtenSam = IOUtil.readFully(is);
+        }
 
-        Assert.assertEquals(writtensam, originalsam);
+        Assert.assertEquals(writtenSam, originalsam);
     }
 
-    @Test(description="Write SAM records with null SAMFileHeader")
-    public void samNullHeaderRoundTrip()  throws Exception  {
+    @Test(description = "Write SAM records with null SAMFileHeader")
+    public void samNullHeaderRoundTrip() throws Exception {
         final File input = new File(TEST_DATA_DIR, "roundtrip.sam");
 
-        final SamReader reader = SamReaderFactory.makeDefault().open(input);
         final File outputFile = File.createTempFile("nullheader-out", ".sam");
         outputFile.delete();
         outputFile.deleteOnExit();
-        FileOutputStream os = new FileOutputStream(outputFile);
         final SAMFileWriterFactory factory = new SAMFileWriterFactory();
-        final SAMFileWriter writer = factory.makeSAMWriter(reader.getFileHeader(), false, os);
-        for (SAMRecord rec : reader) {
-            rec.setHeader(null);
-            writer.addAlignment(rec);
+        try (SamReader reader = SamReaderFactory.makeDefault().open(input);
+             SAMFileWriter writer = factory.makeSAMWriter(reader.getFileHeader(), false, new FileOutputStream(outputFile))) {
+            for (SAMRecord rec : reader) {
+                rec.setHeader(null);
+                writer.addAlignment(rec);
+            }
         }
-        writer.close();
-        os.close();
 
-        InputStream is = new FileInputStream(input);
-        String originalsam = IOUtil.readFully(is);
-        is.close();
+        final String originalsam;
+        try (final InputStream is = new FileInputStream(input)) {
+            originalsam = IOUtil.readFully(is);
+        }
 
-        is = new FileInputStream(outputFile);
-        String writtensam = IOUtil.readFully(is);
-        is.close();
+        final String writtenSam;
+        try (final InputStream is = new FileInputStream(outputFile)) {
+            writtenSam = IOUtil.readFully(is);
+        }
 
-        Assert.assertEquals(writtensam, originalsam);
+        Assert.assertEquals(writtenSam, originalsam);
     }
 
     private void createSmallBam(final File outputFile) {
-        final SAMFileWriterFactory factory = new SAMFileWriterFactory();
-        factory.setCreateIndex(true);
-        factory.setCreateMd5File(true);
-        final SAMFileHeader header = new SAMFileHeader();
-        // index only created if coordinate sorted
-        header.setSortOrder(SAMFileHeader.SortOrder.coordinate);
-        header.addSequence(new SAMSequenceRecord("chr1", 123));
-        try (final SAMFileWriter writer = factory.makeBAMWriter(header, false, outputFile)) {
-            fillSmallBam(writer);
-        }
+        createSmallBam(outputFile.toPath());
     }
 
     private void createSmallBam(final Path outputPath) {
@@ -190,12 +187,12 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
         // index only created if coordinate sorted
         header.setSortOrder(SAMFileHeader.SortOrder.coordinate);
         header.addSequence(new SAMSequenceRecord("chr1", 123));
-        try (final SAMFileWriter writer = factory.makeBAMWriter(header, false, outputPath)) {
+        try (SAMFileWriter writer = factory.makeBAMWriter(header, false, outputPath)) {
             fillSmallBam(writer);
         }
     }
 
-   private void createSmallBamToOutputStream(final OutputStream outputStream,boolean binary) {
+    private void createSmallBamToOutputStream(final OutputStream outputStream, boolean binary) {
         final SAMFileWriterFactory factory = new SAMFileWriterFactory();
         factory.setCreateIndex(false);
         factory.setCreateMd5File(false);
@@ -203,16 +200,17 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
         // index only created if coordinate sorted
         header.setSortOrder(SAMFileHeader.SortOrder.coordinate);
         header.addSequence(new SAMSequenceRecord("chr1", 123));
-        try (final SAMFileWriter writer = (binary?
-        			factory.makeBAMWriter(header, false, outputStream):
-        			factory.makeSAMWriter(header, false, outputStream)
-        			)) {
+
+        try (SAMFileWriter writer = (binary ?
+                factory.makeBAMWriter(header, false, outputStream) :
+                factory.makeSAMWriter(header, false, outputStream)
+        )) {
             fillSmallBam(writer);
         }
     }
 
-    @Test(description="check that factory settings are propagated to writer")
-    public void testFactorySettings()  throws Exception {
+    @Test(description = "check that factory settings are propagated towriter")
+    public void testFactorySettings() throws Exception {
         final SAMFileWriterFactory factory = new SAMFileWriterFactory();
         factory.setCreateIndex(false);
         factory.setCreateMd5File(false);
@@ -233,25 +231,25 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
         }
     }
 
-   private int fillSmallBam(SAMFileWriter writer) {
-       final SAMRecordSetBuilder builder = new SAMRecordSetBuilder();
-       builder.addUnmappedFragment("HiMom!");
-       int numRecs = builder.getRecords().size();
-       for (final SAMRecord rec: builder.getRecords()) {
-           writer.addAlignment(rec);
-       }
-       return numRecs;
+    private int fillSmallBam(final SAMFileWriter writer) {
+        final SAMRecordSetBuilder builder = new SAMRecordSetBuilder();
+        builder.addUnmappedFragment("HiMom!");
+        int numRecs = builder.getRecords().size();
+        for (final SAMRecord rec : builder.getRecords()) {
+            writer.addAlignment(rec);
+        }
+        return numRecs;
     }
 
-    private File prepareOutputFile(String extension) throws IOException {
-        final File outputFile = File.createTempFile("tmp.", extension);
+    private File prepareOutputFileWithSuffix(final String suffix) throws IOException {
+        final File outputFile = File.createTempFile("tmp.", suffix);
         outputFile.delete();
         outputFile.deleteOnExit();
         return outputFile;
     }
 
     //  Create a writer factory that creates and index and md5 file and set the header to coord sorted
-    private SAMFileWriterFactory createWriterFactoryWithOptions(SAMFileHeader header) {
+    private SAMFileWriterFactory createWriterFactoryWithOptions(final SAMFileHeader header) {
         final SAMFileWriterFactory factory = new SAMFileWriterFactory();
         factory.setCreateIndex(true);
         factory.setCreateMd5File(true);
@@ -262,7 +260,21 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
         return factory;
     }
 
-    private void verifyWriterOutput(File outputFile, ReferenceSource refSource, int nRecs, boolean verifySupplementalFiles) {
+    private void verifyWriterOutput(final File outputFile, final ReferenceSource refSource, final int nRecs, final boolean verifySupplementalFiles) throws IOException {
+        if (outputFile.getName().endsWith(SamReader.Type.CRAM_TYPE.fileExtension())) {
+            Assert.assertTrue(SamStreams.isCRAMFile(new BufferedInputStream(new SeekableFileStream(outputFile))));
+        }
+
+        if (outputFile.getName().endsWith(SamReader.Type.BAM_TYPE.fileExtension())) {
+            Assert.assertTrue(SamStreams.isBAMFile(new BufferedInputStream(new SeekableFileStream(outputFile))));
+        }
+
+        if (outputFile.getName().endsWith(SamReader.Type.SAM_TYPE.fileExtension())) {
+            byte[] head = new byte[3];
+            new DataInputStream(new FileInputStream(outputFile)).readFully(head);
+            Assert.assertEquals("@HD".getBytes(), head);
+        }
+
         if (verifySupplementalFiles) {
             final File indexFile = SamFiles.findIndex(outputFile);
             indexFile.deleteOnExit();
@@ -272,18 +284,19 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
             Assert.assertTrue(md5File.length() > 0);
         }
 
-        SamReaderFactory factory =  SamReaderFactory.makeDefault().validationStringency(ValidationStringency.LENIENT);
+        SamReaderFactory factory = SamReaderFactory.makeDefault().validationStringency(ValidationStringency.LENIENT);
         if (refSource != null) {
             factory.referenceSource(refSource);
         }
-        SamReader reader = factory.open(outputFile);
-        SAMRecordIterator it = reader.iterator();
-        int count = 0;
-        for (; it.hasNext(); it.next()) {
-            count++;
-        }
+        try (final SamReader reader = factory.open(outputFile)) {
 
-        Assert.assertTrue(count == nRecs);
+            final SAMRecordIterator it = reader.iterator();
+            int count = 0;
+            for (; it.hasNext(); it.next()) {
+                count++;
+            }
+            Assert.assertTrue(count == nRecs);
+        }
     }
 
     private void verifyWriterOutput(Path output, ReferenceSource refSource, int nRecs, boolean verifySupplementalFiles) throws IOException {
@@ -294,7 +307,7 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
             Assert.assertTrue(Files.size(md5File) > 0);
         }
 
-        SamReaderFactory factory =  SamReaderFactory.makeDefault().validationStringency(ValidationStringency.LENIENT);
+        SamReaderFactory factory = SamReaderFactory.makeDefault().validationStringency(ValidationStringency.LENIENT);
         if (refSource != null) {
             factory.referenceSource(refSource);
         }
@@ -308,29 +321,31 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
         Assert.assertTrue(count == nRecs);
     }
 
-    @DataProvider(name="bamOrCramWriter")
+    @DataProvider(name = "bamOrCramWriter")
     public Object[][] bamOrCramWriter() {
-        return new Object[][] {
-                { BamFileIoUtils.BAM_FILE_EXTENSION, },
-                { CramIO.CRAM_FILE_EXTENSION }
+        return new Object[][]{
+                {SamReader.Type.SAM_TYPE.fileExtension(),},
+                {SamReader.Type.BAM_TYPE.fileExtension(),},
+                {SamReader.Type.CRAM_TYPE.fileExtension()}
         };
     }
 
-    @Test(dataProvider="bamOrCramWriter")
-    public void testMakeWriter(String extension) throws Exception {
-        final File outputFile = prepareOutputFile(extension);
+    @Test(dataProvider = "bamOrCramWriter")
+    public void testMakeWriter(final String extension) throws Exception {
+        final File outputFile = prepareOutputFileWithSuffix("." + extension);
         final SAMFileHeader header = new SAMFileHeader();
         final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
         final File referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta");
 
-        int nRecs;
-        try (final SAMFileWriter samWriter = factory.makeWriter(header, false, outputFile, referenceFile)) {
+        final int nRecs;
+        try (SAMFileWriter samWriter = factory.makeWriter(header, false, outputFile, referenceFile)) {
             nRecs = fillSmallBam(samWriter);
         }
-        verifyWriterOutput(outputFile, new ReferenceSource(referenceFile), nRecs, true);
+
+        verifyWriterOutput(outputFile, new ReferenceSource(referenceFile), nRecs, !SamReader.Type.SAM_TYPE.fileExtension().equals(extension));
     }
 
-    @Test(dataProvider="bamOrCramWriter")
+    @Test(dataProvider = "bamOrCramWriter")
     public void testMakeWriterPath(String extension) throws Exception {
         try (FileSystem jimfs = Jimfs.newFileSystem(Configuration.unix())) {
             Path outputPath = jimfs.getPath("testMakeWriterPath" + extension);
@@ -340,14 +355,14 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
             final Path referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta").toPath();
 
             int nRecs;
-            try (final SAMFileWriter samWriter = factory.makeWriter(header, false, outputPath, referenceFile)) {
+            try (SAMFileWriter samWriter = factory.makeWriter(header, false, outputPath, referenceFile)) {
                 nRecs = fillSmallBam(samWriter);
             }
             verifyWriterOutput(outputPath, new ReferenceSource(referenceFile), nRecs, true);
         }
     }
 
-    @Test(dataProvider="bamOrCramWriter")
+    @Test(dataProvider = "bamOrCramWriter")
     public void testMakeWriterPathAndReferencePath(String extension) throws Exception {
         final String referenceName = "hg19mini.fasta";
         try (FileSystem jimfs = Jimfs.newFileSystem(Configuration.unix())) {
@@ -359,7 +374,7 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
             Files.copy(new File(TEST_DATA_DIR, referenceName).toPath(), referencePath);
 
             int nRecs;
-            try (final SAMFileWriter samWriter = factory.makeWriter(header, false, outputPath, referencePath)) {
+            try (SAMFileWriter samWriter = factory.makeWriter(header, false, outputPath, referencePath)) {
                 nRecs = fillSmallBam(samWriter);
             }
             verifyWriterOutput(outputPath, new ReferenceSource(referencePath), nRecs, true);
@@ -368,43 +383,56 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
 
     @Test
     public void testMakeCRAMWriterWithOptions() throws Exception {
-        final File outputFile = prepareOutputFile(CramIO.CRAM_FILE_EXTENSION);
+        final File outputFile = prepareOutputFileWithSuffix("." + FileExtensions.CRAM);
         final SAMFileHeader header = new SAMFileHeader();
         final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
         final File referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta");
 
-        int nRecs;
-        try (final SAMFileWriter samWriter = factory.makeCRAMWriter(header, false, outputFile, referenceFile)) {
+        final int nRecs;
+        try (SAMFileWriter samWriter = factory.makeCRAMWriter(header, false, outputFile, referenceFile)) {
             nRecs = fillSmallBam(samWriter);
         }
+
         verifyWriterOutput(outputFile, new ReferenceSource(referenceFile), nRecs, true);
     }
 
+    @Test
+    public void testMakeCRAMWriterWithNoReference() throws Exception {
+        final File outputFile = prepareOutputFileWithSuffix("." + FileExtensions.CRAM);
+        final SAMFileHeader header = new SAMFileHeader();
+        final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
+
+        try (SAMFileWriter samWriter = factory.makeCRAMWriter(header, false, outputFile, null)) {
+            fillSmallBam(samWriter);
+        }
+    }
+
     @Test
     public void testMakeCRAMWriterIgnoresOptions() throws Exception {
-        final File outputFile = prepareOutputFile(CramIO.CRAM_FILE_EXTENSION);
+        final File outputFile = prepareOutputFileWithSuffix("." + FileExtensions.CRAM);
         final SAMFileHeader header = new SAMFileHeader();
         final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
         final File referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta");
 
-        int nRecs;
         // Note: does not honor factory settings for CREATE_MD5 or CREATE_INDEX.
-        try (final SAMFileWriter samWriter = factory.makeCRAMWriter(header, new FileOutputStream(outputFile), referenceFile)) {
+        final int nRecs;
+        try (SAMFileWriter samWriter = factory.makeCRAMWriter(header, new FileOutputStream(outputFile), referenceFile)) {
             nRecs = fillSmallBam(samWriter);
         }
+
         verifyWriterOutput(outputFile, new ReferenceSource(referenceFile), nRecs, false);
     }
 
     @Test
     public void testMakeCRAMWriterPresortedDefault() throws Exception {
-        final File outputFile = prepareOutputFile(CramIO.CRAM_FILE_EXTENSION);
+        final File outputFile = prepareOutputFileWithSuffix("." + FileExtensions.CRAM);
         final SAMFileHeader header = new SAMFileHeader();
         final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
         final File referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta");
 
-        int nRecs;
         // Defaults to preSorted==true
-        try (final SAMFileWriter samWriter = factory.makeCRAMWriter(header, outputFile, referenceFile)) {
+        final int nRecs;
+        try (SAMFileWriter samWriter = factory.makeCRAMWriter(header, outputFile, referenceFile)) {
             nRecs = fillSmallBam(samWriter);
         }
 
@@ -415,18 +443,94 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
     public void testAsync() throws IOException {
         final SAMFileWriterFactory builder = new SAMFileWriterFactory();
 
-        final File outputFile = prepareOutputFile(BamFileIoUtils.BAM_FILE_EXTENSION);
+        final File outputFile = prepareOutputFileWithSuffix(FileExtensions.BAM);
         final SAMFileHeader header = new SAMFileHeader();
-        final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
         final File referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta");
 
-        SAMFileWriter writer = builder.makeWriter(header, false, outputFile, referenceFile);
-        Assert.assertEquals(writer instanceof AsyncSAMFileWriter, Defaults.USE_ASYNC_IO_WRITE_FOR_SAMTOOLS, "testAsync default");
+        try (SAMFileWriter writer = builder.makeWriter(header, false, outputFile, referenceFile)) {
+            Assert.assertEquals(writer instanceof AsyncSAMFileWriter, Defaults.USE_ASYNC_IO_WRITE_FOR_SAMTOOLS, "testAsync default");
+        }
 
-        writer = builder.setUseAsyncIo(true).makeWriter(header, false, outputFile, referenceFile);
-        Assert.assertTrue(writer instanceof AsyncSAMFileWriter, "testAsync option=set");
+        try (SAMFileWriter writer = builder.setUseAsyncIo(true).makeWriter(header, false, outputFile, referenceFile)) {
+            Assert.assertTrue(writer instanceof AsyncSAMFileWriter, "testAsync option=set");
+        }
 
-        writer = builder.setUseAsyncIo(false).makeWriter(header, false, outputFile, referenceFile);
-        Assert.assertFalse(writer instanceof AsyncSAMFileWriter, "testAsync option=unset");
+        try (SAMFileWriter writer = builder.setUseAsyncIo(false).makeWriter(header, false, outputFile, referenceFile)) {
+            Assert.assertFalse(writer instanceof AsyncSAMFileWriter, "testAsync option=unset");
+        }
+    }
+
+    @Test
+    public void testMakeWriterForSamExtension() throws IOException {
+        final File tmpFile = File.createTempFile("testMakeWriterForSamExtension", "." + SAM_TYPE.fileExtension());
+        tmpFile.deleteOnExit();
+        try (SAMFileWriter ignored = new SAMFileWriterFactory().makeWriter(new SAMFileHeader(), true, tmpFile, null)) {}
+
+        try (FileInputStream fis = new FileInputStream(tmpFile)) {
+            for (byte b : "@HD\tVN:".getBytes()) {
+                Assert.assertEquals((byte) (fis.read() & 0xFF), b);
+            }
+        }
+    }
+
+    @Test
+    public void testMakeWriterForBamExtension() throws IOException {
+        final File tmpFile = File.createTempFile("testMakeWriterForBamExtension", "." + BAM_TYPE.fileExtension());
+        tmpFile.deleteOnExit();
+        try (SAMFileWriter samFileWriter = new SAMFileWriterFactory().makeWriter(new SAMFileHeader(), true, tmpFile, null)) {}
+
+        Assert.assertTrue(SamStreams.isBAMFile(new BufferedInputStream(new SeekableFileStream(tmpFile))));
+    }
+
+    @Test
+    public void testMakeWriterForCramExtension() throws IOException {
+        final File cramTmpFile = File.createTempFile("testMakeWriterForCramExtension", "." + CRAM_TYPE.fileExtension());
+        cramTmpFile.deleteOnExit();
+        final File refTmpFile = File.createTempFile("testMakeWriterForCramExtension", ".fa");
+        refTmpFile.deleteOnExit();
+        try(SAMFileWriter ignored = new SAMFileWriterFactory().makeWriter(new SAMFileHeader(), true, cramTmpFile, refTmpFile)) {}
+
+        Assert.assertTrue(SamStreams.isCRAMFile(new BufferedInputStream(new SeekableFileStream(cramTmpFile))));
+    }
+
+    @Test(groups = {"defaultReference"})
+    public void testMakeWriterForCramExtensionNoReference() throws IOException {
+        // NOTE: This requires an environment variable that is set in the gradle file for the defaultReference test group
+        final File cramTmpFile = File.createTempFile("testMakeWriterForCramExtension", "." + CRAM_TYPE.fileExtension());
+        cramTmpFile.deleteOnExit();
+        try (SAMFileWriter samFileWriter = new SAMFileWriterFactory().makeWriter(new SAMFileHeader(), true, cramTmpFile, null)) {
+            fillSmallBam(samFileWriter);
+        }
+        Assert.assertTrue(SamStreams.isCRAMFile(new BufferedInputStream(new SeekableFileStream(cramTmpFile))));
+    }
+
+    @Test
+    public void testMakeWriterForNoExtension() throws IOException {
+        final File tmpFile = File.createTempFile("testMakeWriterForNoExtension", "");
+        Assert.assertFalse(tmpFile.getName().contains("."));
+        tmpFile.deleteOnExit();
+        try(SAMFileWriter samFileWriter = new SAMFileWriterFactory().makeWriter(new SAMFileHeader(), true, tmpFile, null)) {}
+        Assert.assertTrue(SamStreams.isBAMFile(new BufferedInputStream(new SeekableFileStream(tmpFile))));
+    }
+
+    @Test
+    public void testMakeWriterForUnknownFileExtension() throws IOException {
+        final File tmpFile = File.createTempFile("testMakeWriterForUnknownFileExtension", ".png");
+        Assert.assertFalse(tmpFile.getName().endsWith(SamReader.Type.CRAM_TYPE.fileExtension()));
+        Assert.assertFalse(tmpFile.getName().endsWith(SamReader.Type.SAM_TYPE.fileExtension()));
+        Assert.assertFalse(tmpFile.getName().endsWith(SamReader.Type.BAM_TYPE.fileExtension()));
+
+        tmpFile.deleteOnExit();
+        try(SAMFileWriter samFileWriter = new SAMFileWriterFactory().makeWriter(new SAMFileHeader(), true, tmpFile, null)){}
+        Assert.assertTrue(SamStreams.isBAMFile(new BufferedInputStream(new SeekableFileStream(tmpFile))));
+    }
+
+    @Test
+    public void testMakeSamOrBamForCramExtension() throws IOException {
+        final File tmpFile = File.createTempFile("testMakeSamOrBamForCramExtension", "." + CRAM_TYPE.fileExtension());
+        tmpFile.deleteOnExit();
+        try(SAMFileWriter samFileWriter = new SAMFileWriterFactory().makeSAMOrBAMWriter(new SAMFileHeader(), true, tmpFile)){}
+
+        Assert.assertTrue(SamStreams.isBAMFile(new BufferedInputStream(new SeekableFileStream(tmpFile))));
     }
 }
