@@ -24,14 +24,18 @@
 package htsjdk.samtools;
 
 import htsjdk.HtsjdkTest;
+import htsjdk.samtools.util.CloserUtil;
 import org.testng.Assert;
 import org.testng.annotations.Test;
 
+import java.io.File;
+import java.io.IOException;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Random;
 
 /**
  * The tests listed here are not exhaustive, and duplicate some of the work found in Picard's MarkDuplicates test classes.
@@ -231,4 +235,43 @@ public class SAMRecordDuplicateComparatorTest extends HtsjdkTest {
         assertEquals(Arrays.asList(-1, -1, -1), records, false);
     }
 
+    @Test()
+    public void sortAndValidate() throws IOException {
+        // Generates synthetic data that is unsorted, it sorts the data, then validates that it was sorted correctly
+
+        // Generate synthetic data
+        final SAMRecordSetBuilder randomSetOfRecords = new SAMRecordSetBuilder(false, SAMFileHeader.SortOrder.unsorted, true);
+        final SAMReadGroupRecord readGroupRecord = new SAMReadGroupRecord("testing_read_group_id");
+        readGroupRecord.setSample("test_sample_name");
+        randomSetOfRecords.setReadGroup(readGroupRecord);
+
+        // The choice of 100000 iterations was done to be large enough to trigger a race condition in htsjdk 2.23.0 and earlier
+        // with a probability > 90%.  Larger numbers of iterations could be used to increase the probability of failure.
+        final Random rand = new Random(42);
+        for (int i = 0;i < 100000;i++) {
+            randomSetOfRecords.addPair("readname" + i, 1, rand.nextInt(1000) + 1, rand.nextInt(1000) + 1);
+        }
+
+        // Sort Bam
+        final File sortedBam = File.createTempFile("testOut",".bam");
+        final SamReader reader = randomSetOfRecords.getSamReader();
+                // SamReaderFactory.makeDefault().referenceSequence(Defaults.REFERENCE_FASTA).open(input);
+        reader.getFileHeader().setSortOrder(SAMFileHeader.SortOrder.duplicate);
+        final SAMFileWriter writer = new SAMFileWriterFactory().makeSAMOrBAMWriter(reader.getFileHeader(), false, sortedBam);
+
+        for (final SAMRecord rec : reader) {
+            writer.addAlignment(rec);
+        }
+        CloserUtil.close(reader);
+        writer.close();
+
+        // Validate that the results are sorted
+        final SAMSortOrderChecker sortChecker = new SAMSortOrderChecker(SAMFileHeader.SortOrder.duplicate);
+        final SamReader r = SamReaderFactory.makeDefault().referenceSequence(Defaults.REFERENCE_FASTA).open(sortedBam);
+
+        for(final SAMRecord rec : r) {
+            Assert.assertTrue(sortChecker.isSorted(rec), "Simulated read with name: " + rec.getReadName() + " is not in duplicate sort order.");
+        }
+    }
+
 }
