@@ -342,12 +342,12 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         Assert.assertNull(record.getUnsignedIntegerAttribute(binaryTag));
 
         record.setAttribute("UI", (long) 0L);
-        Assert.assertEquals(new Long(0L), record.getUnsignedIntegerAttribute(stringTag));
-        Assert.assertEquals(new Long(0L), record.getUnsignedIntegerAttribute(binaryTag));
+        Assert.assertEquals(0L, record.getUnsignedIntegerAttribute(stringTag));
+        Assert.assertEquals(0L, record.getUnsignedIntegerAttribute(binaryTag));
 
         record.setAttribute("UI", BinaryCodec.MAX_UINT);
-        Assert.assertEquals(new Long(BinaryCodec.MAX_UINT), record.getUnsignedIntegerAttribute(stringTag));
-        Assert.assertEquals(new Long(BinaryCodec.MAX_UINT), record.getUnsignedIntegerAttribute(binaryTag));
+        Assert.assertEquals(BinaryCodec.MAX_UINT, record.getUnsignedIntegerAttribute(stringTag));
+        Assert.assertEquals(BinaryCodec.MAX_UINT, record.getUnsignedIntegerAttribute(binaryTag));
 
         final SAMBinaryTagAndValue tv_zero = new SAMBinaryTagAndValue(binaryTag, 0L);
         record = new SAMRecord(header){
@@ -355,17 +355,18 @@ public class SAMRecordUnitTest extends HtsjdkTest {
                 setAttributes(tv_zero);
             }
         };
-        Assert.assertEquals(new Long(0L), record.getUnsignedIntegerAttribute(stringTag));
-        Assert.assertEquals(new Long(0L), record.getUnsignedIntegerAttribute(binaryTag));
+        Assert.assertEquals(0L, record.getUnsignedIntegerAttribute(stringTag));
+        Assert.assertEquals(0L, record.getUnsignedIntegerAttribute(binaryTag));
 
         final SAMBinaryTagAndValue tv_max = new SAMBinaryTagAndValue(binaryTag, BinaryCodec.MAX_UINT);
         record = new SAMRecord(header){
             {
+
                 setAttributes(tv_max);
             }
         };
-        Assert.assertEquals(new Long(BinaryCodec.MAX_UINT), record.getUnsignedIntegerAttribute(stringTag));
-        Assert.assertEquals(new Long(BinaryCodec.MAX_UINT), record.getUnsignedIntegerAttribute(binaryTag));
+        Assert.assertEquals(BinaryCodec.MAX_UINT, record.getUnsignedIntegerAttribute(stringTag));
+        Assert.assertEquals(BinaryCodec.MAX_UINT, record.getUnsignedIntegerAttribute(binaryTag));
     }
 
     /**
@@ -380,11 +381,11 @@ public class SAMRecordUnitTest extends HtsjdkTest {
 
         record = new SAMRecord(header);
         record.setAttribute("UI", 0L);
-        Assert.assertEquals(new Long(0L), record.getUnsignedIntegerAttribute(tag));
+        Assert.assertEquals(0L, record.getUnsignedIntegerAttribute(tag));
 
         record = new SAMRecord(header);
         record.setAttribute("UI", BinaryCodec.MAX_UINT);
-        Assert.assertEquals(new Long(BinaryCodec.MAX_UINT), record.getUnsignedIntegerAttribute("UI"));
+        Assert.assertEquals(BinaryCodec.MAX_UINT, record.getUnsignedIntegerAttribute("UI"));
     }
 
     @Test(expectedExceptions = SAMException.class)
@@ -406,35 +407,35 @@ public class SAMRecordUnitTest extends HtsjdkTest {
     // SAMBinaryTagAndValue, but we'll leave this test here until the code is removed.
     @Test
     public void test_isAllowedAttributeDataType() {
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Byte((byte) 0)));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Short((short) 0)));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Integer(0)));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue("a string"));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Character('C')));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Float(0.1F)));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new byte[]{0}));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new short[]{0}));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new int[]{0}));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new float[]{0.1F}));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue((byte) 0));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue((short) 0));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(0));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue("a string"));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue('C'));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(0.1F));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(new byte[]{0}));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(new short[]{0}));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(new int[]{0}));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(new float[]{0.1F}));
 
         // unsigned integers:
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Long(0)));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Long(BinaryCodec.MAX_UINT)));
-        Assert.assertTrue(SAMRecord.isAllowedAttributeValue(new Long(-1L)));
-        Assert.assertFalse(SAMRecord.isAllowedAttributeValue(new Long(BinaryCodec.MAX_UINT + 1L)));
-        Assert.assertFalse(SAMRecord.isAllowedAttributeValue(new Long(Integer.MIN_VALUE - 1L)));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(0L));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(BinaryCodec.MAX_UINT));
+        Assert.assertTrue(SAMBinaryTagAndValue.isAllowedAttributeValue(-1L));
+        Assert.assertFalse(SAMBinaryTagAndValue.isAllowedAttributeValue(BinaryCodec.MAX_UINT + 1L));
+        Assert.assertFalse(SAMBinaryTagAndValue.isAllowedAttributeValue(Integer.MIN_VALUE - 1L));
     }
 
     @Test()
     public void test_setAttribute_empty_string() {
         final SAMFileHeader header = new SAMFileHeader();
         final SAMRecord record = new SAMRecord(header);
-        Assert.assertNull(record.getStringAttribute(SAMTag.MD.name()));
-        record.setAttribute(SAMTag.MD.name(), "");
-        Assert.assertNotNull(record.getStringAttribute(SAMTag.MD.name()));
-        Assert.assertEquals(record.getStringAttribute(SAMTag.MD.name()),"");
-        record.setAttribute(SAMTag.MD.name(), null);
-        Assert.assertNull(record.getStringAttribute(SAMTag.MD.name()));
+        Assert.assertNull(record.getStringAttribute(SAMTag.MD));
+        record.setAttribute(SAMTag.MD, "");
+        Assert.assertNotNull(record.getStringAttribute(SAMTag.MD));
+        Assert.assertEquals(record.getStringAttribute(SAMTag.MD),"");
+        record.setAttribute(SAMTag.MD, null);
+        Assert.assertNull(record.getStringAttribute(SAMTag.MD));
     }
 
 
@@ -463,7 +464,7 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         Assert.assertNull(record.getUnsignedIntegerAttribute(tag));
 
         record.setAttribute(tag, BinaryCodec.MAX_UINT);
-        Assert.assertEquals(new Long(BinaryCodec.MAX_UINT), record.getUnsignedIntegerAttribute(tag));
+        Assert.assertEquals(BinaryCodec.MAX_UINT, record.getUnsignedIntegerAttribute(tag));
 
         record.setAttribute(tag, null);
         Assert.assertNull(record.getUnsignedIntegerAttribute(tag));
@@ -877,7 +878,7 @@ public class SAMRecordUnitTest extends HtsjdkTest {
 
         // force re-resolution of the reference name against the new header
         sam.setHeaderStrict(newHeader);
-        Assert.assertEquals(sam.getReferenceIndex(), new Integer(0));
+        Assert.assertEquals(sam.getReferenceIndex(), 0);
     }
 
     @Test(expectedExceptions=IllegalArgumentException.class)
@@ -886,7 +887,7 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         final SAMFileHeader samHeader = sam.getHeader();
 
         sam.setReferenceName("unresolvable");
-        Assert.assertEquals(new Integer(SAMRecord.NO_ALIGNMENT_REFERENCE_INDEX), sam.getReferenceIndex());
+        Assert.assertEquals(SAMRecord.NO_ALIGNMENT_REFERENCE_INDEX, sam.getReferenceIndex());
 
         // throw on force re-resolution of the unresolvable reference name
         sam.setHeaderStrict(samHeader);
@@ -898,7 +899,7 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         final SAMFileHeader samHeader = sam.getHeader();
 
         sam.setMateReferenceName("unresolvable");
-        Assert.assertEquals(new Integer(SAMRecord.NO_ALIGNMENT_REFERENCE_INDEX), sam.getMateReferenceIndex());
+        Assert.assertEquals(SAMRecord.NO_ALIGNMENT_REFERENCE_INDEX, sam.getMateReferenceIndex());
 
         // throw on force re-resolution of the unresolvable mate reference name
         sam.setHeaderStrict(samHeader);
@@ -920,7 +921,7 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         final SAMRecord sam = createTestRecordHelper();
         final SAMFileHeader samHeader = sam.getHeader();
         final String contigName = sam.getContig();
-        Assert.assertEquals(SAMRecord.resolveIndexFromName(contigName, samHeader, true), new Integer(samHeader.getSequenceIndex(contigName)));
+        Assert.assertEquals(SAMRecord.resolveIndexFromName(contigName, samHeader, true), samHeader.getSequenceIndex(contigName));
     }
 
     @Test(expectedExceptions=IllegalStateException.class)
@@ -944,7 +945,7 @@ public class SAMRecordUnitTest extends HtsjdkTest {
     public void testResolveIndexNoAlignment() {
         final SAMFileHeader samHeader = new SAMFileHeader();
         Assert.assertEquals(SAMRecord.resolveIndexFromName(
-                SAMRecord.NO_ALIGNMENT_REFERENCE_NAME, samHeader, true), new Integer(SAMRecord.NO_ALIGNMENT_REFERENCE_INDEX));
+                SAMRecord.NO_ALIGNMENT_REFERENCE_NAME, samHeader, true), SAMRecord.NO_ALIGNMENT_REFERENCE_INDEX);
     }
 
     @Test(expectedExceptions=IllegalStateException.class)
@@ -1123,6 +1124,19 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         Assert.assertNull(record.getStringAttribute(ARRAY_TAG));
     }
 
+    @Test
+    public void test_setUnsignedArrayAttribute_empty_array() {
+        final SAMFileHeader header = new SAMFileHeader();
+        final SAMRecord record = new SAMRecord(header);
+        Assert.assertNull(record.getStringAttribute(ARRAY_TAG));
+        record.setUnsignedArrayAttribute(ARRAY_TAG, new int[0]);
+        Assert.assertNotNull(record.getUnsignedIntArrayAttribute(ARRAY_TAG));
+        Assert.assertEquals(record.getUnsignedIntArrayAttribute(ARRAY_TAG), new int[0]);
+        Assert.assertEquals(record.getAttribute(ARRAY_TAG), new char[0]);
+        record.setAttribute(ARRAY_TAG, null);
+        Assert.assertNull(record.getStringAttribute(ARRAY_TAG));
+    }
+
     private static Object[][] getEmptyArrays() {
         return new Object[][]{
                 {new int[0], int[].class},
@@ -1181,4 +1195,14 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         Assert.assertEquals(attribute.getClass(), expectedClass);
         Assert.assertEquals(Array.getLength(attribute), 0);
     }
+
+    @Test
+    public void testAlignmentBlockCacheInvalidation() {
+        final SAMRecord rec = createTestRecordHelper();
+
+        rec.getAlignmentBlocks();
+        Assert.assertEquals(1, rec.getAlignmentBlocks().get(0).getReferenceStart());
+        rec.setAlignmentStart(100);
+        Assert.assertEquals(100, rec.getAlignmentBlocks().get(0).getReferenceStart());
+    }
 }
